@@ -6,6 +6,7 @@
     clippy::match_like_matches_macro,
     clippy::needless_pass_by_value,
     clippy::non_ascii_literal,
+    clippy::option_option,
     clippy::struct_excessive_bools,
     clippy::too_many_lines,
     clippy::trivially_copy_pass_by_ref
@@ -348,22 +349,22 @@ fn apply_args(cmd: &mut Command, args: &Args, color: &Coloring, outfile: &Path)
 
     if let Some(bin) = &args.bin {
         line.arg("--bin");
-        line.arg(bin);
+        line.args(bin);
     }
 
     if let Some(example) = &args.example {
         line.arg("--example");
-        line.arg(example);
+        line.args(example);
     }
 
     if let Some(test) = &args.test {
         line.arg("--test");
-        line.arg(test);
+        line.args(test);
     }
 
     if let Some(bench) = &args.bench {
         line.arg("--bench");
-        line.arg(bench);
+        line.args(bench);
     }
 
     if let Some(target) = &args.target {
@@ -383,7 +384,7 @@ fn apply_args(cmd: &mut Command, args: &Args, color: &Coloring, outfile: &Path)
 
     if let Some(package) = &args.package {
         line.arg("--package");
-        line.arg(package);
+        line.args(package);
     }
 
     if let Some(jobs) = args.jobs {
